@@ -324,11 +324,12 @@ void ServiceResponse::end(const FXchar*) {
 
 FXbool GMAudioScrobbler::post_request(const FXString & url,const FXString & message,FXString & output) {
   FXTRACE((60,"post_request %s - %s\n",url.text(),message.text()));
-  if (client->basic("POST",url,
+  HttpClient client;
+  if (client.basic("POST",url,
                       "Content-Type: application/x-www-form-urlencoded\r\n"
                       "Connection: close\r\n",
                        message)) {
-    output = client->body();
+    output = client.body();
     return true;
     }
   else {
@@ -340,8 +341,9 @@ FXbool GMAudioScrobbler::post_request(const FXString & url,const FXString & mess
 
 FXbool GMAudioScrobbler::get_request(const FXString & url,FXString & output) {
   FXTRACE((60,"get_request\n"));
-  if (client->basic("GET",url,"Connection: close\r\n")) {
-    output = client->body();
+  HttpClient client;
+  if (client.basic("GET",url,"Connection: close\r\n")) {
+    output = client.body();
     return true;
     }
   else {
@@ -372,8 +374,6 @@ GMAudioScrobbler::GMAudioScrobbler(FXObject* tgt,FXSelector msg) :
   nsubmitted(0),
   nfailed(0) {
 
-  client = new HttpClient();
-
   username=FXApp::instance()->reg().readStringEntry("LastFM","username",NULL);
   password=FXApp::instance()->reg().readStringEntry("LastFM","password",NULL);
 
@@ -421,7 +421,6 @@ GMAudioScrobbler::GMAudioScrobbler(FXObject* tgt,FXSelector msg) :
 
 GMAudioScrobbler::~GMAudioScrobbler(){
   save_queue();
-  delete client;
   }
 
 
@@ -1103,6 +1102,7 @@ void GMAudioScrobbler::process_nowplaying_response(const FXString & response){
     if (!service.parse(response) || !service.getStatus()) {
       FXTRACE((60,"last.fm service failed with code %d: %s\n",service.getErrorCode(),service.getErrorMessage().text()));
       switch(service.getErrorCode()) {
+        case LASTFM_ERROR_UNKNOWN      :
         case LASTFM_ERROR_OFFLINE      :
         case LASTFM_ERROR_UNAVAILABLE  : set_timeout();           break;
         case LASTFM_ERROR_BADSESSION   : session.clear();         break;
@@ -1307,8 +1307,9 @@ void GMAudioScrobbler::process_submit_response(const FXString & response){
     if (!service.parse(response) || !service.getStatus()) {
       FXTRACE((60,"last.fm service failed with code %d: %s\n",service.getErrorCode(),service.getErrorMessage().text()));
       switch(service.getErrorCode()) {
+        case LASTFM_ERROR_UNKNOWN      :
         case LASTFM_ERROR_OFFLINE      :
-        case LASTFM_ERROR_UNAVAILABLE  : set_timeout(); break;
+        case LASTFM_ERROR_UNAVAILABLE  : set_timeout();           break;
         case LASTFM_ERROR_BADSESSION   : session.clear();         break;
         case LASTFM_ERROR_KEY_INVALID  :
         case LASTFM_ERROR_KEY_SUSPENDED: flags|=FLAG_BANNED;      break;
