@@ -46,9 +46,6 @@ enum {
   SERVICE_CUSTOM
   };
 
-namespace ap {
-  class HttpClient;
-  };
 
 class GMAudioScrobbler : public FXThread {
 private:
@@ -60,8 +57,6 @@ private:
   FXObject*         target;
   FXSelector        message;
   FXbool            started;
-private:
-  ap::HttpClient*       client;
 private:
   FXuint            mode;
   FXString          handshake_url;
