@@ -550,9 +550,11 @@ void parse(GMTrack & track,const FXString & mask,FXuint options) {
           case 'p' : if (options&OVERWRITE || track.artist.empty()) track.artist.adopt(field); break;
           case 'n' :
 #if FOXVERSION >= FXVERSION(1,7,12)
-          case 'N' : if (options&OVERWRITE) track.no = field.toInt(); break;
+          case 'N' : if (options&OVERWRITE) track.setTrackNumber(field.toInt()); break;
+          case 'd' : if (options&OVERWRITE) track.setDiscNumber(field.toInt()); break;
 #else
-          case 'N' : if (options&OVERWRITE) track.no = FXIntVal(field); break;
+          case 'N' : if (options&OVERWRITE) track.setTrackNumber(FXIntVal(field)); break;
+          case 'd' : if (options&OVERWRITE) track.setDiscNumber(FXIntVal(field)); break;
 #endif
           }
         //fxmessage("%%%c=\"%s\"\n",item,field.text());
