@@ -387,6 +387,9 @@ void GMIconTheme::build() {
       iconsets[current].medium.adopt(mediumpath);
       iconsets[current].large.adopt(largepath);
       }
+            
+    delete [] index;
+    delete [] inherits;            
     }
   }
 
