@@ -28,14 +28,14 @@
 #include "GMImportDialog.h"
 
 
-extern const FXchar gmfilepatterns[]="All Music (*.mp3,*.ogg,*.oga,*.flac,*.mpc"
+extern const FXchar gmfilepatterns[]="All Music (*.mp3,*.ogg,*.oga,*.flac,*.mpc,*.wav"
 #if defined(TAGLIB_WITH_MP4) && (TAGLIB_WITH_MP4==1)
 ",*.aac,*.m4a,*.m4p,*.mp4,*.m4b"
 #endif
 #if defined(TAGLIB_WITH_ASF) && (TAGLIB_WITH_ASF==1)
 ",*.wma,*.asf"
 #endif
-")\nFree Lossless Audio Codec (*.flac)\n"
+")\nFree Lossless Audio Codec (*.flac)\nWaveform Audio File Format (*.wav)\n"
 "MPEG-1 Audio Layer 3 (*.mp3)\n"
 #if defined(TAGLIB_WITH_MP4) && (TAGLIB_WITH_MP4==1)
 "MPEG-4 Part 14 (*.mp4,*.m4a,*.m4p,*.aac,*.m4b)\n"
@@ -107,14 +107,6 @@ GMDirSelector::GMDirSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint
   dirbox->setAssociations(filedict);
   delete old;
 #endif
-/*
-  getFirst()->hide();
-  FXFrame * frame=(FXFrame*)getFirst()->getNext();
-  frame->setPadLeft(0);
-  frame->setPadRight(0);
-  frame->setPadTop(0);
-  frame->setPadBottom(0);
-*/
   }
 
 GMDirSelector::~GMDirSelector(){
@@ -287,6 +279,7 @@ static const FXchar * const filetypes[]={
   "ogg",";Ogg Vorbis",
   "oga",";Ogg Audio",
   "flac",";Free Lossless Audio Codec",
+  "wav",";Waveform Audio File Format",
   "mpc",";Musepack",
 #if defined(TAGLIB_WITH_ASF) && (TAGLIB_WITH_ASF==1)
   "wma",";Windows Media",
@@ -692,6 +685,7 @@ void GMImportDialog::getDefaultSearchDirectory(FXString & directory){
     "ogg",
     "OGG",
     "Ogg",
+    "wav",
 #if defined(TAGLIB_WITH_MP4) && (TAGLIB_WITH_MP4==1)
     "mp4",
     "MP4",
