@@ -221,7 +221,6 @@ const ColorTheme ColorThemes[]={
 FXDEFMAP(GMPreferencesDialog) GMPreferencesDialogMap[]={
   FXMAPFUNC(SEL_COMMAND,GMPreferencesDialog::ID_LASTFM_SCROBBLE,GMPreferencesDialog::onCmdLastFMScrobble),
   FXMAPFUNC(SEL_COMMAND,GMPreferencesDialog::ID_LASTFM_SERVICE,GMPreferencesDialog::onCmdLastFMService),
-
   FXMAPFUNC(SEL_COMMAND,GMPreferencesDialog::ID_LASTFM_USERNAME,GMPreferencesDialog::onCmdLastFMUserName),
   FXMAPFUNC(SEL_CHANGED,GMPreferencesDialog::ID_LASTFM_USERNAME,GMPreferencesDialog::onCmdLastFMUserName),
   FXMAPFUNC(SEL_FOCUSIN,GMPreferencesDialog::ID_LASTFM_PASSWORD,GMPreferencesDialog::onFocusLastFMPassWord),
@@ -306,9 +305,11 @@ GMPreferencesDialog::GMPreferencesDialog(FXWindow * p) : FXDialogBox(p,FXString:
     }
 #endif
 
+
   grpbox =  new FXGroupBox(vframe,tr("Last.fm"),FRAME_NONE|LAYOUT_FILL_X,0,0,0,0,23,3,0,0,0,0);
   grpbox->setFont(GMApp::instance()->getThickFont());
 
+
   if (GMPlayerManager::instance()->getAudioScrobbler()->isBanned()) {
     new FXLabel(grpbox,tr("This version of Goggles Music Manager is\n"
                        "not supported by Last-FM. Please upgrade\n"
@@ -339,10 +340,11 @@ GMPreferencesDialog::GMPreferencesDialog(FXWindow * p) : FXDialogBox(p,FXString:
     if (current_service==SERVICE_CUSTOM) lastfm_join->hide();
 
 
-    new FXLabel(matrix,tr("Username:"),NULL,labelstyle);
+    lastfm_username_label = new FXLabel(matrix,tr("Username:"),NULL,labelstyle);
     lastfm_username = new GMTextField(matrix,20,this,ID_LASTFM_USERNAME,FRAME_SUNKEN|FRAME_THICK);
-    new FXLabel(matrix,tr("Password:"),NULL,labelstyle);
+    lastfm_password_label = new FXLabel(matrix,tr("Password:"),NULL,labelstyle);
     lastfm_password = new GMTextField(matrix,20,this,ID_LASTFM_PASSWORD,FRAME_SUNKEN|FRAME_THICK|TEXTFIELD_PASSWD);
+
     new FXFrame(matrix,FRAME_NONE);
     lastfm_scrobble = new GMCheckButton(grpbox,tr("Scrobble"),this,ID_LASTFM_SCROBBLE,LAYOUT_FIX_X|LAYOUT_FIX_Y|CHECKBUTTON_NORMAL,6,0);
     lastfm_scrobble->setFont(GMApp::instance()->getThickFont());
@@ -352,8 +354,22 @@ GMPreferencesDialog::GMPreferencesDialog(FXWindow * p) : FXDialogBox(p,FXString:
       lastfm_password->setText("1234567890");
 
     lastfm_scrobble->setCheck(GMPlayerManager::instance()->getAudioScrobbler()->isEnabled());
+
+    if (current_service==SERVICE_LASTFM){
+      lastfm_username->hide();
+      lastfm_username_label->hide();
+      lastfm_password->hide();
+      lastfm_password_label->hide();
+      }
+    else {
+      lastfm_username->show();
+      lastfm_username_label->show();
+      lastfm_password->show();
+      lastfm_password_label->show();
+      }
     }
 
+
   new GMTabItem(tabbook,tr("&Window"),NULL,TAB_TOP_NORMAL,0,0,0,0,5,5);
   vframe = new GMTabFrame(tabbook);
 
@@ -701,6 +717,13 @@ long GMPreferencesDialog::onCmdIconTheme(FXObject*,FXSelector,void*){
   }
 
 
+
+
+
+
+
+
+
 long GMPreferencesDialog::onCmdLastFMScrobble(FXObject*,FXSelector,void*){
   if (lastfm_scrobble->getCheck())
     GMPlayerManager::instance()->getAudioScrobbler()->enable();
@@ -712,6 +735,8 @@ long GMPreferencesDialog::onCmdLastFMScrobble(FXObject*,FXSelector,void*){
 
 long GMPreferencesDialog::onCmdLastFMService(FXObject*,FXSelector,void*){
   if (lastfm_service->getCurrentItem()!=SERVICE_CUSTOM) {
+
+
     GMPlayerManager::instance()->getAudioScrobbler()->service(lastfm_service->getCurrentItem());
     lastfm_username->setText(FXString::null,false);
     lastfm_password->setText(FXString::null,false);
@@ -722,6 +747,19 @@ long GMPreferencesDialog::onCmdLastFMService(FXObject*,FXSelector,void*){
       }
     lastfm_join->show();
     }
+
+  if (lastfm_service->getCurrentItem()==SERVICE_LASTFM){
+    lastfm_username->hide();
+    lastfm_username_label->hide();
+    lastfm_password->hide();
+    lastfm_password_label->hide();
+    }
+  else {
+    lastfm_username->show();
+    lastfm_username_label->show();
+    lastfm_password->show();
+    lastfm_password_label->show();
+    }
   return 1;
   }
 
@@ -769,7 +807,6 @@ long GMPreferencesDialog::onCmdLastFMJoin(FXObject*,FXSelector,void*){
   }
 
 
-
 long GMPreferencesDialog::onCmdElementColor(FXObject*,FXSelector sel,void* rgba) {
   FXColor color = (FXColor)(FXuval)rgba;
 
