@@ -332,15 +332,8 @@ void GMImportThread::import(){
       }
     else if (FXStat::isFile(files[i])) {
       ext = FXPath::extension(files[i]);
-/*      
-      if (comparecase(ext,"m3u")==0 ||
-          comparecase(ext,"xspf")==0) ||
-          comparecase(ext,"pls")==0) {        
-        playlists.append(files[i]);            
-        }    
-*/      
-      
-      if (comparecase(ext,"mp3")==0 || comparecase(ext,"ogg")==0 || comparecase(ext,"oga")==0 || comparecase(ext,"flac")==0 || comparecase(ext,"mpc")==0
+
+      if (comparecase(ext,"mp3")==0 || comparecase(ext,"ogg")==0 || comparecase(ext,"oga")==0 || comparecase(ext,"flac")==0 || comparecase(ext,"mpc")==0 || comparecase(ext,"wav")==0
 #if defined(TAGLIB_WITH_ASF) && (TAGLIB_WITH_ASF==1)
       || comparecase(ext,"wma")==0 || comparecase(ext,"asf")==0
 #endif
@@ -414,7 +407,7 @@ void GMImportThread::listDirectory(const FXString & dir) {
 
   if (!running) return;
 
-  no=FXDir::listFiles(files,dir,"*.(ogg,oga,mp3,mpc,flac"
+  no=FXDir::listFiles(files,dir,"*.(ogg,oga,mp3,mpc,flac,wav"
 #if defined(TAGLIB_WITH_MP4) && (TAGLIB_WITH_MP4==1)
        ",mp4,m4a,aac,m4p,m4b"
 #endif
