@@ -542,6 +542,11 @@ HttpHost::HttpHost(const FXString & url) {
   set(url);
   }
 
+void HttpHost::clear() {
+  name.clear();
+  port=0;
+  }
+
 FXbool HttpHost::set(const FXString & url) {
   FXString nn = GMURL::host(url);
   FXint    np = GMURL::port(url);
@@ -831,9 +836,11 @@ FXbool HttpClient::request(const FXchar * method,const FXString & url,const FXSt
     }
 
   // Open connection if necessary
-  if (device==BadHandle && !open_connection())
+  if (device==BadHandle && !open_connection()){
+    server.clear();
     return false;
-
+    }
+    
   // Extract path and query
   path  = GMURL::path(url);
   if (path.empty())
@@ -977,6 +984,18 @@ FXbool HttpClient::basic(const FXchar*    method,
               }
           } break;
 
+        case HTTP_RESPONSE_FAILED:  /* something went wrong */
+          {
+#ifdef DEBUG
+            fxmessage("HttpClient::basic() - Response Failed:\n");
+            FXString b((const FXchar*)buffer->data(),buffer->size());
+            fxmessage("%s\n",b.text());
+#endif
+            return false;
+            break;
+          }
+
+
         default: break;
         }
       return true;
